@@ -11,11 +11,11 @@
 #![feature(alloc_layout_extra)]
 #![feature(allocator_api)]
 #![feature(asm)]
-#![feature(const_fn)]
 #![feature(const_fn_fn_ptr_basics)]
 #![feature(const_fn_transmute)]
 #![feature(const_panic)]
 #![feature(const_ptr_is_null)]
+#![feature(const_ptr_offset_from)]
 #![cfg_attr(not(debug_assertions), feature(const_unreachable_unchecked))]
 #![feature(core_intrinsics)]
 #![feature(extend_one)]
